@@ -48,6 +48,8 @@ ev_document_get_type (void)
 		type = g_type_register_static (G_TYPE_INTERFACE,
 					       "EvDocument",
 					       &our_info, (GTypeFlags)0);
+		
+		g_type_interface_add_prerequisite (type, G_TYPE_OBJECT);
 	}
 
 	return type;
@@ -89,6 +91,12 @@ ev_document_doc_mutex_unlock (void)
 	g_mutex_unlock (ev_document_get_doc_mutex ());
 }
 
+gboolean
+ev_document_doc_mutex_trylock (void)
+{
+	return g_mutex_trylock (ev_document_get_doc_mutex ());
+}
+
 GMutex *
 ev_document_get_fc_mutex (void)
 {
@@ -110,6 +118,12 @@ ev_document_fc_mutex_unlock (void)
 	g_mutex_unlock (ev_document_get_fc_mutex ());
 }
 
+gboolean
+ev_document_fc_mutex_trylock (void)
+{
+	return g_mutex_trylock (ev_document_get_fc_mutex ());
+}
+
 gboolean
 ev_document_load (EvDocument  *document,
 		  const char  *uri,
