@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ev-file-helpers.c 2858 2008-01-25 12:30:28Z carlosgc $
+ *  $Id: ev-file-helpers.c 3318 2008-12-31 15:58:06Z carlosgc $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -62,15 +62,10 @@ ev_dot_dir (void)
 	if (dot_dir == NULL) {
 		gboolean exists;
 
-#if WITH_GNOME
-		dot_dir = g_build_filename (gnome_user_dir_get (),
+		dot_dir = g_build_filename (g_get_home_dir (),
+					    ".gnome2",
 					    "evince",
 					    NULL);
-#else
-		dot_dir = g_build_filename (g_get_user_config_dir (),
-					    "evince",
-					    NULL);
-#endif
 
 		exists = ensure_dir_exists (dot_dir);
 		if (!exists)
@@ -174,17 +169,19 @@ void
 ev_tmp_file_unlink (GFile *file)
 {
 	gboolean res;
+	GError  *error = NULL;
 
 	if (!file)
 		return;
 	
-	res = g_file_delete (file, NULL, NULL);
+	res = g_file_delete (file, NULL, &error);
 	if (!res) {
 		char *uri;
 		
 		uri = g_file_get_uri (file);
-		g_warning ("Unable to delete temp file %s\n", uri);
+		g_warning ("Unable to delete temp file %s: %s\n", uri, error->message);
 		g_free (uri);
+		g_error_free (error);
 	}
 }
 
@@ -214,7 +211,7 @@ ev_xfer_uri_simple (const char *from,
 {
 	GFile *source_file;
 	GFile *target_file;
-	GError *ioerror;
+	GError *ioerror = NULL;
 	gboolean result;
 	
 	if (!from)
@@ -237,6 +234,67 @@ ev_xfer_uri_simple (const char *from,
 
 }
 
+static gchar *
+get_mime_type_from_uri (const gchar *uri, GError **error)
+{
+	GFile     *file;
+	GFileInfo *file_info;
+	gchar     *mime_type;
+
+	file = g_file_new_for_uri (uri);
+	file_info = g_file_query_info (file,
+				       G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+				       0, NULL, error);
+	g_object_unref (file);
+
+	if (file_info == NULL)
+		return NULL;
+
+	mime_type = g_content_type_get_mime_type (
+			g_file_info_get_content_type (file_info));
+	g_object_unref (file_info);
+
+	return mime_type;
+}
+
+static gchar *
+get_mime_type_from_data (const gchar *uri, GError **error)
+{
+	GFile            *file;
+	GFileInputStream *input_stream;
+	gssize            size_read;
+	guchar            buffer[1024];
+
+	file = g_file_new_for_uri (uri);
+	
+	input_stream = g_file_read (file, NULL, error);
+	if (!input_stream) {
+		g_object_unref (file);
+		return NULL;
+	}
+
+	size_read = g_input_stream_read (G_INPUT_STREAM (input_stream),
+					 buffer, 1024, NULL, NULL);
+	g_input_stream_close (G_INPUT_STREAM (input_stream), NULL, error);
+
+	g_object_unref (file);
+
+	if (size_read == -1)
+		return NULL;
+
+	return g_content_type_guess (NULL, /* no filename */
+				     buffer, 1024,
+				     NULL);
+}
+
+gchar *
+ev_file_get_mime_type (const gchar *uri,
+		       gboolean     fast,
+		       GError     **error)
+{
+	return fast ? get_mime_type_from_uri (uri, error) : get_mime_type_from_data (uri, error);
+}
+
 /* Compressed files support */
 #define BZIPCOMMAND "bzip2"
 #define GZIPCOMMAND "gzip"
